import { Cell, Checkbox, CheckboxGroup, Icon, Image, Sticky } from 'vant';
import { defineComponent, onMounted, reactive, ref, watch } from 'vue';
import styles from '../index.module.less';
// import badge1 from '../images/badge-1.png';
import MSearch from '@/components/m-search';
import activeButtonIcon from '@/common/images/icon-check-active.png';
import inactiveButtonIcon from '@/common/images/icon-check.png';
import iconStudent from '@/common/images/icon-student-default.png';
import iconTeacher from '@/common/images/icon-teacher-default.png';
import request from '@/helpers/request';
export default defineComponent({
  name: 'contacts-modal',
  props: {
    height: {
      type: [Number],
      default: 0
    },
    bottomHeight: {
      type: [String, Number],
      default: 0
    },
    headerHeight: {
      type: [Number],
      default: 0
    },
    selectItem: {
      type: Array,
      default: () => []
    }
  },
  emits: ['update:selectItem'],
  setup(props, { emit }) {
    const checkboxRefs = ref([] as any);
    const forms = reactive({
      height: props.height,
      list: [],
      check: [] as any
    });

    const onToggle = (index: number) => {
      //
      checkboxRefs.value[index].toggle();

      const list: any = [];
      forms.list.forEach((item: any) => {
        if (forms.check.includes(item.id)) {
          list.push({
            id: item.id,
            value: item.friendNickname,
            text: item.memo,
            avatar:
              item.friend.avatar || item.friend.userType === 'TEACHER'
                ? iconTeacher
                : iconStudent
          });
        }
      });
      emit('update:selectItem', list);
    };

    watch(
      () => props.height,
      () => {
        forms.height = props.height;
      }
    );

    watch(
      () => props.selectItem,
      () => {
        initSelectItem();
      },
      { deep: true }
    );

    const initSelectItem = () => {
      const selectItem = props.selectItem || [];
      const temp: any = [];
      selectItem.forEach((item: any) => {
        temp.push(item.id);
      });
      forms.check = temp;
    };

    const getList = async () => {
      try {
        const { data } = await request.post(
          '/api-web/imGroup/schoolQueryFriendList'
        );
        forms.list = data || [];
      } catch {
        //
      }
    };

    onMounted(() => {
      getList();
    });
    return () => (
      <div
        style={{
          'min-height': `calc(100vh - ${props.headerHeight}px - ${forms.height}px - ${props.bottomHeight}px )`
        }}>
        <Sticky
          position="top"
          offsetTop={props.headerHeight + forms.height}
          style={{ width: '100%' }}>
          <MSearch placeholder="请输入群聊名称" />
        </Sticky>
        <CheckboxGroup v-model={forms.check}>
          {forms.list.map((item: any, index: number) => (
            <Cell
              center
              onClick={() => onToggle(index)}
              class={styles.popupCell}>
              {{
                icon: () => (
                  <Image
                    src={
                      item.friend.avatar || item.friend.userType === 'TEACHER'
                        ? iconTeacher
                        : iconStudent
                    }
                    class={styles.imgLogo}
                    fit="contain"
                  />
                ),
                title: () => (
                  <div class={styles.infos}>
                    <div class={styles.infoTitle}>
                      {item.friendNickname}
                      {/* <img src={badge1} class={styles.iconBadge} /> */}
                    </div>
                    <div class={styles.infoContent}>{item.memo}</div>
                  </div>
                ),
                'right-icon': () => (
                  <Checkbox
                    name={item.id}
                    ref={e => (checkboxRefs.value[index] = e)}
                    onClick={(e: MouseEvent) => {
                      e.stopPropagation();
                    }}
                    v-slots={{
                      icon: (props: any) => (
                        <Icon
                          class={styles.boxStyle}
                          name={
                            props.checked
                              ? activeButtonIcon
                              : inactiveButtonIcon
                          }
                        />
                      )
                    }}
                  />
                )
              }}
            </Cell>
          ))}
        </CheckboxGroup>
      </div>
    );
  }
});
