import { defineComponent, onMounted, reactive } from 'vue';
import styles from './index.module.less';
import Item from './item';
import { Button, Cell, Field, Skeleton, SkeletonParagraph, showToast } from 'vant';
import MSticky from '@/components/m-sticky';
import MHeader from '@/components/m-header';
import SkeletionDetailItem from './skeletion-detail-item';
import { useRoute } from 'vue-router';
import { MusicGroupQuitDetailDto } from '../schedule';
import {
  api_musicGroupQuitAuditPass,
  api_musicGroupQuitAuditReject,
  api_musicGroupQuitGetDetail
} from '../api';

export default defineComponent({
  name: 'schedule-manage-detail',
  setup() {
    const route = useRoute();
    const detailData = reactive({
      student: {} as MusicGroupQuitDetailDto,
      skeleton: true
    });

    /** 获取退团详情 */
    const getDetail = async () => {
      const musicGroupQuitId: string = route.query.musicGroupQuitId as any;
      api_musicGroupQuitGetDetail(musicGroupQuitId)
        .then(res => {
          const data: MusicGroupQuitDetailDto = res?.data || {};
          detailData.student = data;
        })
        .finally(() => {
          detailData.skeleton = false;
        });
    };

    /** 通过 */
    const musicGroupQuitAuditPass = async () => {
      await api_musicGroupQuitAuditPass(
        detailData.student.musicGroupQuitId,
        detailData.student.reasonEnum
      );
      showToast('操作成功')
    };
    /** 拒绝 */
    const musicGroupQuitAuditReject = async () => {
      await api_musicGroupQuitAuditReject(
        detailData.student.musicGroupQuitId,
        detailData.student.reasonEnum
      );
      showToast('操作成功')
    };
    onMounted(() => {
      getDetail();
    });
    return () => (
      <div class={styles.detail}>
        <MSticky position="top">
          <MHeader></MHeader>
        </MSticky>

        <Skeleton loading={detailData.skeleton}>
          {{
            template: () => (
              <div style={{ width: '100%' }}>
                <SkeletionDetailItem />
              </div>
            ),
            default: () => <Item />
          }}
        </Skeleton>

        <div class={styles.item}>
          <div class={styles.itemTitleDes}>
            <div class={styles.line}></div>
            <div>退团原因</div>
          </div>
          <Skeleton class={styles.skeleton} loading={detailData.skeleton}>
            {{
              template: () => (
                <div class={styles.info}>
                  <SkeletonParagraph />
                  <SkeletonParagraph />
                </div>
              ),
              default: () => <div class={styles.info}>毕业</div>
            }}
          </Skeleton>

          <div class={styles.itemTitleDes}>
            <div class={styles.line}></div>
            <div>具体原因</div>
          </div>

          <Skeleton class={styles.skeleton} loading={detailData.skeleton}>
            {{
              template: () => (
                <div class={styles.info}>
                  <SkeletonParagraph />
                  <SkeletonParagraph />
                </div>
              ),
              default: () => (
                <div class={styles.info}>
                  孩子快升学了，需要专心学习文化课。
                </div>
              )
            }}
          </Skeleton>
        </div>
        <div class={styles.item}>
          <div class={styles.itemTitleDes}>
            <div class={styles.line}></div>
            <div>
              审批意见 <span style={{ color: 'red' }}>*</span>
            </div>
          </div>

          <Skeleton class={styles.skeleton} loading={detailData.skeleton}>
            {{
              template: () => (
                <div class={styles.info}>
                  <SkeletonParagraph />
                  <SkeletonParagraph />
                </div>
              ),
              default: () => (
                <>
                  {detailData.student.status === 'ING' ? (
                    <Field
                      required
                      rows={2}
                      type="textarea"
                      placeholder="请输入审批意见"
                      border={false}
                    />
                  ) : (
                    <div class={styles.info}>
                      这次比赛很有希望，不要留下遗憾，乐团需要你！
                    </div>
                  )}
                </>
              )
            }}
          </Skeleton>
        </div>

        {!detailData.skeleton && detailData.student.status !== 'ING' && (
          <div class={styles.item}>
            <div class={styles.itemTitleDes}>
              <div class={styles.line}></div>
              <div>审批时间</div>
            </div>
            <div class={styles.info}>2023-03-24 14:20:32</div>
          </div>
        )}

        {detailData.skeleton && detailData.student.status === 'ING' && (
          <div class={[styles.btns, 'van-safe-area-bottom']}>
            <Button
              class={styles.cancelBtn}
              round
              block
              onClick={musicGroupQuitAuditReject}>
              拒绝
            </Button>
            <Button
              type="primary"
              round
              block
              onClick={musicGroupQuitAuditPass}>
              通过
            </Button>
          </div>
        )}
      </div>
    );
  }
});
