import { PropType, defineComponent } from 'vue';
import styles from './index.module.less';
import icontimer from '@/common/images/icon-timer.png';
import iconTeacher from '@/common/images/icon-teacher-default.png';
import iconIm from '@/common/images/icon-im.png';
import { Cell, Image } from 'vant';
import icon_cancel from './icons/icon-cancel.png';
import icon_comfirm from './icons/icon-comfirm.png';
import { MusicGroupQuitDetailDto } from '../schedule';
import { postMessage } from '@/helpers/native-message';

export default defineComponent({
  name: 'schedule-manage-list-item',
  props: {
    status: {
      type: String as PropType<'success' | 'error'>,
      default: ''
    },
    item: {
      type: Object as PropType<MusicGroupQuitDetailDto>,
      default: () => ({})
    }
  },
  emits: ['goto'],
  setup(props, { emit }) {
    const item = props.item;
    
    /** 去聊天 */
    const openIm = () => {
      postMessage({
        api: 'joinChatGroup',
        content: {
          type: 'single', // single 单人 multi 多人
          id: item.studentId
        }
      })
    }
    return () => (
      <div class={styles.item_box}>
        <div class={styles.listItem}>
          <div class={styles.itemTop}>
            <img class={styles.icon} src={icontimer} />
            <span class={styles.timeTitle}>审批时间：</span>
            <span class={styles.time}>
              {item.createTime || '2023-03-24 14:00:32'}
            </span>
          </div>
          <Cell center label={item.subjectName || '长笛'}>
            {{
              icon: () => (
                <Image
                  src={item.studentAvatar || iconTeacher}
                  class={styles.iconTeacher}
                  fit="contain"
                />
              ),
              title: () => (
                <div class={styles.cellTitle}>
                  <span>{item.studentName || '李天泽'}</span>
                  <img class={styles.iconIm} src={iconIm} onClick={() => openIm()} />
                </div>
              )
            }}
          </Cell>
        </div>
        {item.status !== 'ING' && (
          <img
            class={styles.iconResult}
            src={item.status === 'PASS' ? icon_comfirm : icon_cancel}
          />
        )}
      </div>
    );
  }
});
