import { PropType, defineComponent } from 'vue';
import styles from './index.module.less';
import icontimer from '@/common/images/icon-timer.png';
import iconTeacher from '@/common/images/icon-teacher-default.png';
import { Cell, Image } from 'vant';
import { MusicGroupQuitPageDto } from './schedule';

export default defineComponent({
  name: 'schedule-manage-list-item',
  props: {
    status: {
      type: String as PropType<'success' | 'error'>,
      default: ''
    },
    item: {
      type: Object as PropType<MusicGroupQuitPageDto>,
      default: () => ({})
    }
  },
  emits: ['goto'],
  setup(props, { emit }) {
    const item = props.item
    return () => (
      <div class={styles.listItem}>
        <div class={styles.itemTop}>
          <img class={styles.icon} src={icontimer} />
          <span class={styles.timeTitle}>审批时间：</span>
          <span class={styles.time}>{item.createTime}</span>
          {props.status === 'success' && (
            <div class={[styles.timeBtn, styles.success]}>已通过</div>
          )}
          {props.status === 'error' && (
            <div class={[styles.timeBtn, styles.error]}>未通过</div>
          )}
        </div>
        <Cell
          center
          title={item.studentName}
          label={item.subjectName}
          value={'退团申请'}
          isLink
          onClick={() => emit('goto')}>
          {{
            icon: () => (
              <Image
                src={item.studentAvatar || iconTeacher}
                class={styles.iconTeacher}
                fit="contain"
              />
            )
          }}
        </Cell>
      </div>
    );
  }
});
